# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_agama_global_optspecs
	string join \n host= insecure h/help
end

function __fish_agama_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_agama_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_agama_using_subcommand
	set -l cmd (__fish_agama_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c agama -n "__fish_agama_needs_command" -l host -d 'URI pointing to Agama\'s remote host' -r
complete -c agama -n "__fish_agama_needs_command" -l insecure -d 'Whether to accept invalid (self-signed, ...) certificates or not'
complete -c agama -n "__fish_agama_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_needs_command" -f -a "config" -d 'Inspect or change the installation settings'
complete -c agama -n "__fish_agama_needs_command" -f -a "probe" -d 'Analyze the system'
complete -c agama -n "__fish_agama_needs_command" -f -a "install" -d 'Start the system installation'
complete -c agama -n "__fish_agama_needs_command" -f -a "profile" -d 'Manage auto-installation profiles (retrieving, applying, etc.)'
complete -c agama -n "__fish_agama_needs_command" -f -a "questions" -d 'Handle installer questions'
complete -c agama -n "__fish_agama_needs_command" -f -a "logs" -d 'Collect the installer logs'
complete -c agama -n "__fish_agama_needs_command" -f -a "auth" -d 'Authenticate with Agama\'s server'
complete -c agama -n "__fish_agama_needs_command" -f -a "download" -d 'Download file from given URL'
complete -c agama -n "__fish_agama_needs_command" -f -a "finish" -d 'Finish the installation'
complete -c agama -n "__fish_agama_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c agama -n "__fish_agama_using_subcommand config; and not __fish_seen_subcommand_from show load edit help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand config; and not __fish_seen_subcommand_from show load edit help" -f -a "show" -d 'Generate an installation profile with the current settings'
complete -c agama -n "__fish_agama_using_subcommand config; and not __fish_seen_subcommand_from show load edit help" -f -a "load" -d 'Read and load a profile from the standard input'
complete -c agama -n "__fish_agama_using_subcommand config; and not __fish_seen_subcommand_from show load edit help" -f -a "edit" -d 'Edit and update installation option using an external editor'
complete -c agama -n "__fish_agama_using_subcommand config; and not __fish_seen_subcommand_from show load edit help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c agama -n "__fish_agama_using_subcommand config; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand config; and __fish_seen_subcommand_from load" -s h -l help -d 'Print help'
complete -c agama -n "__fish_agama_using_subcommand config; and __fish_seen_subcommand_from edit" -s e -l editor -d 'Editor command (including additional arguments if needed)' -r
complete -c agama -n "__fish_agama_using_subcommand config; and __fish_seen_subcommand_from edit" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "show" -d 'Generate an installation profile with the current settings'
complete -c agama -n "__fish_agama_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "load" -d 'Read and load a profile from the standard input'
complete -c agama -n "__fish_agama_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "edit" -d 'Edit and update installation option using an external editor'
complete -c agama -n "__fish_agama_using_subcommand config; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c agama -n "__fish_agama_using_subcommand probe" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand install" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand profile; and not __fish_seen_subcommand_from autoyast validate evaluate import help" -s h -l help -d 'Print help'
complete -c agama -n "__fish_agama_using_subcommand profile; and not __fish_seen_subcommand_from autoyast validate evaluate import help" -f -a "autoyast" -d 'Download the autoyast profile and print resulting json'
complete -c agama -n "__fish_agama_using_subcommand profile; and not __fish_seen_subcommand_from autoyast validate evaluate import help" -f -a "validate" -d 'Validate a profile using JSON Schema'
complete -c agama -n "__fish_agama_using_subcommand profile; and not __fish_seen_subcommand_from autoyast validate evaluate import help" -f -a "evaluate" -d 'Evaluate a profile, injecting the hardware information from D-Bus'
complete -c agama -n "__fish_agama_using_subcommand profile; and not __fish_seen_subcommand_from autoyast validate evaluate import help" -f -a "import" -d 'Process autoinstallation profile and loads it into agama'
complete -c agama -n "__fish_agama_using_subcommand profile; and not __fish_seen_subcommand_from autoyast validate evaluate import help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c agama -n "__fish_agama_using_subcommand profile; and __fish_seen_subcommand_from autoyast" -s h -l help -d 'Print help'
complete -c agama -n "__fish_agama_using_subcommand profile; and __fish_seen_subcommand_from validate" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand profile; and __fish_seen_subcommand_from evaluate" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand profile; and __fish_seen_subcommand_from import" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand profile; and __fish_seen_subcommand_from help" -f -a "autoyast" -d 'Download the autoyast profile and print resulting json'
complete -c agama -n "__fish_agama_using_subcommand profile; and __fish_seen_subcommand_from help" -f -a "validate" -d 'Validate a profile using JSON Schema'
complete -c agama -n "__fish_agama_using_subcommand profile; and __fish_seen_subcommand_from help" -f -a "evaluate" -d 'Evaluate a profile, injecting the hardware information from D-Bus'
complete -c agama -n "__fish_agama_using_subcommand profile; and __fish_seen_subcommand_from help" -f -a "import" -d 'Process autoinstallation profile and loads it into agama'
complete -c agama -n "__fish_agama_using_subcommand profile; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c agama -n "__fish_agama_using_subcommand questions; and not __fish_seen_subcommand_from mode answers list ask help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand questions; and not __fish_seen_subcommand_from mode answers list ask help" -f -a "mode" -d 'Set the mode for answering questions'
complete -c agama -n "__fish_agama_using_subcommand questions; and not __fish_seen_subcommand_from mode answers list ask help" -f -a "answers" -d 'Load predefined answers'
complete -c agama -n "__fish_agama_using_subcommand questions; and not __fish_seen_subcommand_from mode answers list ask help" -f -a "list" -d 'Prints the list of questions that are waiting for an answer in JSON format'
complete -c agama -n "__fish_agama_using_subcommand questions; and not __fish_seen_subcommand_from mode answers list ask help" -f -a "ask" -d 'Reads a question definition in JSON from stdin and prints the response when it is answered'
complete -c agama -n "__fish_agama_using_subcommand questions; and not __fish_seen_subcommand_from mode answers list ask help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c agama -n "__fish_agama_using_subcommand questions; and __fish_seen_subcommand_from mode" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand questions; and __fish_seen_subcommand_from answers" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand questions; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c agama -n "__fish_agama_using_subcommand questions; and __fish_seen_subcommand_from ask" -s h -l help -d 'Print help'
complete -c agama -n "__fish_agama_using_subcommand questions; and __fish_seen_subcommand_from help" -f -a "mode" -d 'Set the mode for answering questions'
complete -c agama -n "__fish_agama_using_subcommand questions; and __fish_seen_subcommand_from help" -f -a "answers" -d 'Load predefined answers'
complete -c agama -n "__fish_agama_using_subcommand questions; and __fish_seen_subcommand_from help" -f -a "list" -d 'Prints the list of questions that are waiting for an answer in JSON format'
complete -c agama -n "__fish_agama_using_subcommand questions; and __fish_seen_subcommand_from help" -f -a "ask" -d 'Reads a question definition in JSON from stdin and prints the response when it is answered'
complete -c agama -n "__fish_agama_using_subcommand questions; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c agama -n "__fish_agama_using_subcommand logs; and not __fish_seen_subcommand_from store list help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand logs; and not __fish_seen_subcommand_from store list help" -f -a "store" -d 'Collect and store the logs in a tar archive'
complete -c agama -n "__fish_agama_using_subcommand logs; and not __fish_seen_subcommand_from store list help" -f -a "list" -d 'List the logs to collect'
complete -c agama -n "__fish_agama_using_subcommand logs; and not __fish_seen_subcommand_from store list help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c agama -n "__fish_agama_using_subcommand logs; and __fish_seen_subcommand_from store" -s d -l destination -d 'Path to destination directory and, optionally, the archive file name. The extension will be added automatically' -r -F
complete -c agama -n "__fish_agama_using_subcommand logs; and __fish_seen_subcommand_from store" -s h -l help -d 'Print help'
complete -c agama -n "__fish_agama_using_subcommand logs; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c agama -n "__fish_agama_using_subcommand logs; and __fish_seen_subcommand_from help" -f -a "store" -d 'Collect and store the logs in a tar archive'
complete -c agama -n "__fish_agama_using_subcommand logs; and __fish_seen_subcommand_from help" -f -a "list" -d 'List the logs to collect'
complete -c agama -n "__fish_agama_using_subcommand logs; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c agama -n "__fish_agama_using_subcommand auth; and not __fish_seen_subcommand_from login logout show help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand auth; and not __fish_seen_subcommand_from login logout show help" -f -a "login" -d 'Authenticate with Agama\'s server and store the token'
complete -c agama -n "__fish_agama_using_subcommand auth; and not __fish_seen_subcommand_from login logout show help" -f -a "logout" -d 'Deauthenticate by removing the token'
complete -c agama -n "__fish_agama_using_subcommand auth; and not __fish_seen_subcommand_from login logout show help" -f -a "show" -d 'Print the used token to the standard output'
complete -c agama -n "__fish_agama_using_subcommand auth; and not __fish_seen_subcommand_from login logout show help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c agama -n "__fish_agama_using_subcommand auth; and __fish_seen_subcommand_from login" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand auth; and __fish_seen_subcommand_from logout" -s h -l help -d 'Print help'
complete -c agama -n "__fish_agama_using_subcommand auth; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help'
complete -c agama -n "__fish_agama_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "login" -d 'Authenticate with Agama\'s server and store the token'
complete -c agama -n "__fish_agama_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "logout" -d 'Deauthenticate by removing the token'
complete -c agama -n "__fish_agama_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "show" -d 'Print the used token to the standard output'
complete -c agama -n "__fish_agama_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c agama -n "__fish_agama_using_subcommand download" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand finish" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c agama -n "__fish_agama_using_subcommand help; and not __fish_seen_subcommand_from config probe install profile questions logs auth download finish help" -f -a "config" -d 'Inspect or change the installation settings'
complete -c agama -n "__fish_agama_using_subcommand help; and not __fish_seen_subcommand_from config probe install profile questions logs auth download finish help" -f -a "probe" -d 'Analyze the system'
complete -c agama -n "__fish_agama_using_subcommand help; and not __fish_seen_subcommand_from config probe install profile questions logs auth download finish help" -f -a "install" -d 'Start the system installation'
complete -c agama -n "__fish_agama_using_subcommand help; and not __fish_seen_subcommand_from config probe install profile questions logs auth download finish help" -f -a "profile" -d 'Manage auto-installation profiles (retrieving, applying, etc.)'
complete -c agama -n "__fish_agama_using_subcommand help; and not __fish_seen_subcommand_from config probe install profile questions logs auth download finish help" -f -a "questions" -d 'Handle installer questions'
complete -c agama -n "__fish_agama_using_subcommand help; and not __fish_seen_subcommand_from config probe install profile questions logs auth download finish help" -f -a "logs" -d 'Collect the installer logs'
complete -c agama -n "__fish_agama_using_subcommand help; and not __fish_seen_subcommand_from config probe install profile questions logs auth download finish help" -f -a "auth" -d 'Authenticate with Agama\'s server'
complete -c agama -n "__fish_agama_using_subcommand help; and not __fish_seen_subcommand_from config probe install profile questions logs auth download finish help" -f -a "download" -d 'Download file from given URL'
complete -c agama -n "__fish_agama_using_subcommand help; and not __fish_seen_subcommand_from config probe install profile questions logs auth download finish help" -f -a "finish" -d 'Finish the installation'
complete -c agama -n "__fish_agama_using_subcommand help; and not __fish_seen_subcommand_from config probe install profile questions logs auth download finish help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from config" -f -a "show" -d 'Generate an installation profile with the current settings'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from config" -f -a "load" -d 'Read and load a profile from the standard input'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from config" -f -a "edit" -d 'Edit and update installation option using an external editor'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from profile" -f -a "autoyast" -d 'Download the autoyast profile and print resulting json'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from profile" -f -a "validate" -d 'Validate a profile using JSON Schema'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from profile" -f -a "evaluate" -d 'Evaluate a profile, injecting the hardware information from D-Bus'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from profile" -f -a "import" -d 'Process autoinstallation profile and loads it into agama'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from questions" -f -a "mode" -d 'Set the mode for answering questions'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from questions" -f -a "answers" -d 'Load predefined answers'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from questions" -f -a "list" -d 'Prints the list of questions that are waiting for an answer in JSON format'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from questions" -f -a "ask" -d 'Reads a question definition in JSON from stdin and prints the response when it is answered'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from logs" -f -a "store" -d 'Collect and store the logs in a tar archive'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from logs" -f -a "list" -d 'List the logs to collect'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from auth" -f -a "login" -d 'Authenticate with Agama\'s server and store the token'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from auth" -f -a "logout" -d 'Deauthenticate by removing the token'
complete -c agama -n "__fish_agama_using_subcommand help; and __fish_seen_subcommand_from auth" -f -a "show" -d 'Print the used token to the standard output'
